/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/shlex-67ee55856bda7043.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/bytes.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libshlex-67ee55856bda7043.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/bytes.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libshlex-67ee55856bda7043.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/bytes.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/lib.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/shlex-1.3.0/src/bytes.rs:
