/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/scopeguard-04b5d676fcb98f60.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/scopeguard-1.2.0/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libscopeguard-04b5d676fcb98f60.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/scopeguard-1.2.0/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libscopeguard-04b5d676fcb98f60.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/scopeguard-1.2.0/src/lib.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/scopeguard-1.2.0/src/lib.rs:
