/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/serde_value-c0310a813265b99b.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/ser.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libserde_value-c0310a813265b99b.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/ser.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libserde_value-c0310a813265b99b.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/ser.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/lib.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/de.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-value-0.7.0/src/ser.rs:
