/home/andreu/projectstuff/inline-lua/ffi/target/release/build/serde-49df78e293254ff4/build_script_build-49df78e293254ff4.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/serde-49df78e293254ff4/build_script_build-49df78e293254ff4: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/build.rs:
