/home/andreu/projectstuff/inline-lua/ffi/target/release/build/num-traits-41922b01dcfc1c55/build_script_build-41922b01dcfc1c55.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/num-traits-0.2.19/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/num-traits-41922b01dcfc1c55/build_script_build-41922b01dcfc1c55: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/num-traits-0.2.19/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/num-traits-0.2.19/build.rs:
