/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/serde-0dd7a4c17bd27874.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/integer128.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/value.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/ignored_any.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/impls.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/size_hint.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/fmt.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impls.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impossible.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/format.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/doc.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/seed.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libserde-0dd7a4c17bd27874.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/integer128.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/value.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/ignored_any.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/impls.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/size_hint.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/fmt.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impls.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impossible.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/format.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/doc.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/seed.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libserde-0dd7a4c17bd27874.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/integer128.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/value.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/ignored_any.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/impls.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/size_hint.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/fmt.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impls.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impossible.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/format.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/doc.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/seed.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/lib.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/macros.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/integer128.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/mod.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/value.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/ignored_any.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/impls.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/size_hint.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/mod.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/fmt.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impls.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/ser/impossible.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/format.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/mod.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/de.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/ser.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/private/doc.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde-1.0.219/src/de/seed.rs:
