/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/serde_json-8f129b2f8a4ff78c.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/map.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/from.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/index.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/partial_eq.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/io/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/iter.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/number.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/read.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libserde_json-8f129b2f8a4ff78c.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/map.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/from.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/index.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/partial_eq.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/io/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/iter.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/number.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/read.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libserde_json-8f129b2f8a4ff78c.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/map.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/de.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/from.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/index.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/partial_eq.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/ser.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/io/mod.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/iter.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/number.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/read.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/lib.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/macros.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/de.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/error.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/map.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/ser.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/mod.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/de.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/from.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/index.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/partial_eq.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/value/ser.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/io/mod.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/iter.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/number.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/src/read.rs:
