/home/andreu/projectstuff/inline-lua/ffi/target/release/build/parking_lot_core-d3863d002d09745b/build_script_build-d3863d002d09745b.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/parking_lot_core-0.9.11/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/parking_lot_core-d3863d002d09745b/build_script_build-d3863d002d09745b: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/parking_lot_core-0.9.11/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/parking_lot_core-0.9.11/build.rs:
