/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/rustversion-f032d3c2e70e3be2.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/attr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/bound.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/constfn.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/date.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/expand.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/iter.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/release.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/time.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/token.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/version.rs /home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustversion-da2a80cb00e385be/out/version.expr

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/librustversion-f032d3c2e70e3be2.so: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/attr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/bound.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/constfn.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/date.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/expand.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/iter.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/release.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/time.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/token.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/version.rs /home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustversion-da2a80cb00e385be/out/version.expr

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/lib.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/attr.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/bound.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/constfn.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/date.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/error.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/expand.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/expr.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/iter.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/release.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/time.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/token.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/src/version.rs:
/home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustversion-da2a80cb00e385be/out/version.expr:

# env-dep:OUT_DIR=/home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustversion-da2a80cb00e385be/out
