/home/andreu/projectstuff/inline-lua/ffi/target/release/build/proc-macro2-bcf07a371b2fc1ac/build_script_build-bcf07a371b2fc1ac.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/proc-macro2-1.0.95/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/proc-macro2-bcf07a371b2fc1ac/build_script_build-bcf07a371b2fc1ac: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/proc-macro2-1.0.95/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/proc-macro2-1.0.95/build.rs:
