/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/smallvec-9065d6bb449b1ef5.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/smallvec-1.15.1/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libsmallvec-9065d6bb449b1ef5.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/smallvec-1.15.1/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libsmallvec-9065d6bb449b1ef5.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/smallvec-1.15.1/src/lib.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/smallvec-1.15.1/src/lib.rs:
