/home/andreu/projectstuff/inline-lua/ffi/target/release/build/serde_json-d55d69208000e138/build_script_build-d55d69208000e138.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/serde_json-d55d69208000e138/build_script_build-d55d69208000e138: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/serde_json-1.0.140/build.rs:
