/home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustversion-4c1953679e14a857/build_script_build-4c1953679e14a857.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/build/build.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/build/rustc.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustversion-4c1953679e14a857/build_script_build-4c1953679e14a857: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/build/build.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/build/rustc.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/build/build.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustversion-1.0.21/build/rustc.rs:
