/* This is a generated file. DO NOT EDIT! */

FFDEF(assert)
FFDEF(type)
FFDEF(next)
FFDEF(pairs)
FFDEF(ipairs_aux)
FFDEF(ipairs)
FFDEF(getmetatable)
FFDEF(setmetatable)
FFDEF(getfenv)
FFDEF(setfenv)
FFDEF(rawget)
FFDEF(rawset)
FFDEF(rawequal)
FFDEF(unpack)
FFDEF(select)
FFDEF(tonumber)
FFDEF(tostring)
FFDEF(error)
FFDEF(pcall)
FFDEF(xpcall)
FFDEF(loadfile)
FFDEF(load)
FFDEF(loadstring)
FFDEF(dofile)
FFDEF(gcinfo)
FFDEF(collectgarbage)
FFDEF(newproxy)
FFDEF(print)
FFDEF(coroutine_status)
FFDEF(coroutine_running)
FFDEF(coroutine_isyieldable)
FFDEF(coroutine_create)
FFDEF(coroutine_yield)
FFDEF(coroutine_resume)
FFDEF(coroutine_wrap_aux)
FFDEF(coroutine_wrap)
FFDEF(math_abs)
FFDEF(math_floor)
FFDEF(math_ceil)
FFDEF(math_sqrt)
FFDEF(math_log10)
FFDEF(math_exp)
FFDEF(math_sin)
FFDEF(math_cos)
FFDEF(math_tan)
FFDEF(math_asin)
FFDEF(math_acos)
FFDEF(math_atan)
FFDEF(math_sinh)
FFDEF(math_cosh)
FFDEF(math_tanh)
FFDEF(math_frexp)
FFDEF(math_modf)
FFDEF(math_log)
FFDEF(math_atan2)
FFDEF(math_pow)
FFDEF(math_fmod)
FFDEF(math_ldexp)
FFDEF(math_min)
FFDEF(math_max)
FFDEF(math_random)
FFDEF(math_randomseed)
FFDEF(bit_tobit)
FFDEF(bit_bnot)
FFDEF(bit_bswap)
FFDEF(bit_lshift)
FFDEF(bit_rshift)
FFDEF(bit_arshift)
FFDEF(bit_rol)
FFDEF(bit_ror)
FFDEF(bit_band)
FFDEF(bit_bor)
FFDEF(bit_bxor)
FFDEF(bit_tohex)
FFDEF(string_byte)
FFDEF(string_char)
FFDEF(string_sub)
FFDEF(string_rep)
FFDEF(string_reverse)
FFDEF(string_lower)
FFDEF(string_upper)
FFDEF(string_dump)
FFDEF(string_find)
FFDEF(string_match)
FFDEF(string_gmatch_aux)
FFDEF(string_gmatch)
FFDEF(string_gsub)
FFDEF(string_format)
FFDEF(table_maxn)
FFDEF(table_insert)
FFDEF(table_concat)
FFDEF(table_sort)
FFDEF(table_new)
FFDEF(table_clear)
FFDEF(io_method_close)
FFDEF(io_method_read)
FFDEF(io_method_write)
FFDEF(io_method_flush)
FFDEF(io_method_seek)
FFDEF(io_method_setvbuf)
FFDEF(io_method_lines)
FFDEF(io_method___gc)
FFDEF(io_method___tostring)
FFDEF(io_open)
FFDEF(io_popen)
FFDEF(io_tmpfile)
FFDEF(io_close)
FFDEF(io_read)
FFDEF(io_write)
FFDEF(io_flush)
FFDEF(io_input)
FFDEF(io_output)
FFDEF(io_lines)
FFDEF(io_type)
FFDEF(os_execute)
FFDEF(os_remove)
FFDEF(os_rename)
FFDEF(os_tmpname)
FFDEF(os_getenv)
FFDEF(os_exit)
FFDEF(os_clock)
FFDEF(os_date)
FFDEF(os_time)
FFDEF(os_difftime)
FFDEF(os_setlocale)
FFDEF(debug_getregistry)
FFDEF(debug_getmetatable)
FFDEF(debug_setmetatable)
FFDEF(debug_getfenv)
FFDEF(debug_setfenv)
FFDEF(debug_getinfo)
FFDEF(debug_getlocal)
FFDEF(debug_setlocal)
FFDEF(debug_getupvalue)
FFDEF(debug_setupvalue)
FFDEF(debug_upvalueid)
FFDEF(debug_upvaluejoin)
FFDEF(debug_sethook)
FFDEF(debug_gethook)
FFDEF(debug_debug)
FFDEF(debug_traceback)
FFDEF(jit_on)
FFDEF(jit_off)
FFDEF(jit_flush)
FFDEF(jit_status)
FFDEF(jit_security)
FFDEF(jit_attach)
FFDEF(jit_util_funcinfo)
FFDEF(jit_util_funcbc)
FFDEF(jit_util_funck)
FFDEF(jit_util_funcuvname)
FFDEF(jit_util_traceinfo)
FFDEF(jit_util_traceir)
FFDEF(jit_util_tracek)
FFDEF(jit_util_tracesnap)
FFDEF(jit_util_tracemc)
FFDEF(jit_util_traceexitstub)
FFDEF(jit_util_ircalladdr)
FFDEF(jit_opt_start)
FFDEF(jit_profile_start)
FFDEF(jit_profile_stop)
FFDEF(jit_profile_dumpstack)
FFDEF(ffi_meta___index)
FFDEF(ffi_meta___newindex)
FFDEF(ffi_meta___eq)
FFDEF(ffi_meta___len)
FFDEF(ffi_meta___lt)
FFDEF(ffi_meta___le)
FFDEF(ffi_meta___concat)
FFDEF(ffi_meta___call)
FFDEF(ffi_meta___add)
FFDEF(ffi_meta___sub)
FFDEF(ffi_meta___mul)
FFDEF(ffi_meta___div)
FFDEF(ffi_meta___mod)
FFDEF(ffi_meta___pow)
FFDEF(ffi_meta___unm)
FFDEF(ffi_meta___tostring)
FFDEF(ffi_meta___pairs)
FFDEF(ffi_meta___ipairs)
FFDEF(ffi_clib___index)
FFDEF(ffi_clib___newindex)
FFDEF(ffi_clib___gc)
FFDEF(ffi_callback_free)
FFDEF(ffi_callback_set)
FFDEF(ffi_cdef)
FFDEF(ffi_new)
FFDEF(ffi_cast)
FFDEF(ffi_typeof)
FFDEF(ffi_typeinfo)
FFDEF(ffi_istype)
FFDEF(ffi_sizeof)
FFDEF(ffi_alignof)
FFDEF(ffi_offsetof)
FFDEF(ffi_errno)
FFDEF(ffi_string)
FFDEF(ffi_copy)
FFDEF(ffi_fill)
FFDEF(ffi_abi)
FFDEF(ffi_metatype)
FFDEF(ffi_gc)
FFDEF(ffi_load)
FFDEF(buffer_method_free)
FFDEF(buffer_method_reset)
FFDEF(buffer_method_skip)
FFDEF(buffer_method_set)
FFDEF(buffer_method_put)
FFDEF(buffer_method_putf)
FFDEF(buffer_method_get)
FFDEF(buffer_method_putcdata)
FFDEF(buffer_method_reserve)
FFDEF(buffer_method_commit)
FFDEF(buffer_method_ref)
FFDEF(buffer_method_encode)
FFDEF(buffer_method_decode)
FFDEF(buffer_method___gc)
FFDEF(buffer_method___tostring)
FFDEF(buffer_method___len)
FFDEF(buffer_new)
FFDEF(buffer_encode)
FFDEF(buffer_decode)

#undef FFDEF

#ifndef FF_NUM_ASMFUNC
#define FF_NUM_ASMFUNC 57
#endif

