/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/syn-b7b3bf4840615440.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/group.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/token.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/attr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/bigint.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/buffer.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/classify.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_keyword.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_punctuation.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/data.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/derive.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/drops.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ext.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/fixup.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/generics.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ident.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lifetime.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lit.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lookahead.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/mac.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/meta.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/op.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/discouraged.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_macro_input.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_quote.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/path.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/precedence.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/print.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/punctuated.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/restriction.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/sealed.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/scan_expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/span.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/spanned.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/thread.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ty.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/verbatim.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/export.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/gen/clone.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libsyn-b7b3bf4840615440.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/group.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/token.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/attr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/bigint.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/buffer.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/classify.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_keyword.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_punctuation.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/data.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/derive.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/drops.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ext.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/fixup.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/generics.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ident.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lifetime.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lit.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lookahead.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/mac.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/meta.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/op.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/discouraged.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_macro_input.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_quote.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/path.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/precedence.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/print.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/punctuated.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/restriction.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/sealed.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/scan_expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/span.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/spanned.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/thread.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ty.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/verbatim.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/export.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/gen/clone.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libsyn-b7b3bf4840615440.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lib.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/macros.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/group.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/token.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/attr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/bigint.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/buffer.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/classify.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_keyword.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_punctuation.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/data.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/derive.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/drops.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/error.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ext.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/fixup.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/generics.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ident.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lifetime.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lit.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lookahead.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/mac.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/meta.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/op.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/discouraged.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_macro_input.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_quote.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/path.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/precedence.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/print.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/punctuated.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/restriction.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/sealed.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/scan_expr.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/span.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/spanned.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/thread.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ty.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/verbatim.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/export.rs /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/gen/clone.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lib.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/macros.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/group.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/token.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/attr.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/bigint.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/buffer.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/classify.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_keyword.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/custom_punctuation.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/data.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/derive.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/drops.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/error.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/expr.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ext.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/fixup.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/generics.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ident.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lifetime.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lit.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/lookahead.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/mac.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/meta.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/op.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/discouraged.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_macro_input.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/parse_quote.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/path.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/precedence.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/print.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/punctuated.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/restriction.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/sealed.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/scan_expr.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/span.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/spanned.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/thread.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/ty.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/verbatim.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/export.rs:
/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/syn-2.0.104/src/gen/clone.rs:
