/home/andreu/projectstuff/inline-lua/ffi/target/release/build/libc-d943ea62dcb30ccc/build_script_build-d943ea62dcb30ccc.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/libc-0.2.174/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/libc-d943ea62dcb30ccc/build_script_build-d943ea62dcb30ccc: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/libc-0.2.174/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/libc-0.2.174/build.rs:
