/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/typeid-8cfb39aec3997f7b.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/typeid-1.0.3/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libtypeid-8cfb39aec3997f7b.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/typeid-1.0.3/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libtypeid-8cfb39aec3997f7b.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/typeid-1.0.3/src/lib.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/typeid-1.0.3/src/lib.rs:
