/home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustix-abb72dd9bd7937a9/build_script_build-abb72dd9bd7937a9.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustix-1.0.7/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/rustix-abb72dd9bd7937a9/build_script_build-abb72dd9bd7937a9: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustix-1.0.7/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/rustix-1.0.7/build.rs:
