/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/luajit_src-ef65d26df0be30c3.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/luajit-src-210.5.12+a4f56a4/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libluajit_src-ef65d26df0be30c3.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/luajit-src-210.5.12+a4f56a4/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libluajit_src-ef65d26df0be30c3.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/luajit-src-210.5.12+a4f56a4/src/lib.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/luajit-src-210.5.12+a4f56a4/src/lib.rs:

# env-dep:CARGO_MANIFEST_DIR=/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/luajit-src-210.5.12+a4f56a4
