/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/env_home-2eedf23c78630c60.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/env_home-0.1.0/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libenv_home-2eedf23c78630c60.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/env_home-0.1.0/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libenv_home-2eedf23c78630c60.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/env_home-0.1.0/src/lib.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/env_home-0.1.0/src/lib.rs:
