/home/andreu/projectstuff/inline-lua/ffi/target/release/build/typeid-829cebce2c94891b/build_script_build-829cebce2c94891b.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/typeid-1.0.3/build.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/build/typeid-829cebce2c94891b/build_script_build-829cebce2c94891b: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/typeid-1.0.3/build.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/typeid-1.0.3/build.rs:
