/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/pkg_config-732ea8d9fd7e6dbb.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/pkg-config-0.3.32/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libpkg_config-732ea8d9fd7e6dbb.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/pkg-config-0.3.32/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/libpkg_config-732ea8d9fd7e6dbb.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/pkg-config-0.3.32/src/lib.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/pkg-config-0.3.32/src/lib.rs:
