/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/lua_src-bd1e64da43a6d9f7.d: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/lua-src-547.0.0/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/liblua_src-bd1e64da43a6d9f7.rlib: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/lua-src-547.0.0/src/lib.rs

/home/andreu/projectstuff/inline-lua/ffi/target/release/deps/liblua_src-bd1e64da43a6d9f7.rmeta: /home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/lua-src-547.0.0/src/lib.rs

/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/lua-src-547.0.0/src/lib.rs:

# env-dep:CARGO_MANIFEST_DIR=/home/andreu/.cargo/registry/src/index.crates.io-1949cf8c6b5b557f/lua-src-547.0.0
